%define shortname	statgrab

Summary:		Make system statistics
Name:			libstatgrab

Version:		0.16
Release:		3%{?dist}

Source0:		http://ftp.i-scream.org/pub/i-scream/%{name}/%{name}-%{version}.tar.gz
Patch0:			%{name}.nochmod.patch

License:		LGPLv2+
Group:			System Environment/Libraries
URL:			http://www.i-scream.org/%{name}/

BuildRoot:		%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	libtool ncurses-devel

%description
Libstatgrab is a library that provides cross platform access to statistics
about the system on which it's run. It's written in C and presents a selection
of useful interfaces which can be used to access key system statistics. The
current list of statistics includes CPU usage, memory utilisation, disk usage,
process counts, network traffic, disk I/O, and more. 

The current list of platforms is Solaris 2.x, Linux, and FreeBSD 4.x/5.x.
The aim is to extend this to include as many operating systems as possible. 

The package also includes a couple of useful tools. The first, saidar,
provides a curses-based interface to viewing the current state of the 
system. The second, statgrab, gives a sysctl-style interface to the
statistics gathered by libstatgrab. This extends the use of libstatgrab
to people writing scripts or anything else that can't easily make C 
function calls. Included with statgrab is a script to generate an MRTG
configuration file to use statgrab. 

%package -n %{shortname}-tools
Summary: Tools from %{name} to monitoring the system
License: GPLv2+
Group: Applications/System

%description -n %{shortname}-tools
This package contains a few tools shiped with libstatgrab.
Eg. A tool called saidar, which shows various system
information like top, but - of course - OTHER informations.

%package devel
Summary: The development files from %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package contains header files and man pages for those
use to develop libstatgrab based applications.

%package examples
Summary: The example files from %{name}
License: GPLv2+
Group: Development/Tools
Requires: %{name} = %{version}-%{release}

%description examples
This package contains various examples used to show how
to develop libstatgrab based applications.

%prep
%setup -q
%patch0 -p0

%build
%configure --with-ncurses

# remove rpath from libtool
# shamelessly stolen from cinepaint.spec (thanks!)
sed -i.rpath 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i.rpath 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
cd examples/.libs
install -m 755 cpu_usage disk_traffic load_stats network_iface_stats \
	network_traffic os_info page_stats process_snapshot \
	process_stats user_list vm_stats $RPM_BUILD_ROOT%{_bindir}
chmod 755 $RPM_BUILD_ROOT%{_bindir}/statgrab-make-mrtg-config
chmod 755 $RPM_BUILD_ROOT%{_bindir}/saidar
chmod 755 $RPM_BUILD_ROOT%{_bindir}/statgrab

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -n %shortname-tools
%defattr(-,root,root)
%doc COPYING
%{_bindir}/saidar
%{_bindir}/statgrab
%{_bindir}/statgrab-make-mrtg-config
%{_bindir}/statgrab-make-mrtg-index
%{_mandir}/*/statgrab*
%{_mandir}/*/saidar*

%files
%defattr(-,root,root)
%doc AUTHORS INSTALL README ChangeLog NEWS COPYING.LGPL examples/*.c
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/*.la
%{_includedir}/*.h
%{_libdir}/pkgconfig/%name.pc
%{_mandir}/*/sg_*

%files examples
%defattr(-,root,root)
%{_bindir}/cpu_usage
%{_bindir}/disk_traffic
%{_bindir}/load_stats
%{_bindir}/network_iface_stats
%{_bindir}/network_traffic
%{_bindir}/os_info
%{_bindir}/page_stats
%{_bindir}/process_snapshot
%{_bindir}/process_stats
%{_bindir}/user_list
%{_bindir}/vm_stats

%changelog
* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.16-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Mar 20 2008 Oliver Falk <oliver@linux-kernel.at> 0.16-1
- Update

* Wed Feb 13 2008 Patrick "Jima" Laughton <jima@beer.tclug.org> 0.15-2
- Bump-n-build for GCC 4.3

* Mon Aug 20 2007 Patrick "Jima" Laughton <jima@beer.tclug.org> 0.15-1
- New upstream version
- License clarification
- Fixed License tags for statgrab-tools and libstatgrab-examples
- Fix for rpath (problem found in previous versions, as well)

* Wed Jan 24 2007 Patrick "Jima" Laughton <jima@beer.tclug.org> 0.14-1
- New upstream version
- Minor cleanup for rpmlint warning

* Wed Oct 04 2006 Patrick "Jima" Laughton <jima@beer.tclug.org> 0.13-3
- Bump-n-build

* Tue Sep 19 2006 Patrick "Jima" Laughton <jima@beer.tclug.org>	- 0.13-2
- Bump for FC6 rebuild

* Thu Apr 20 2006 Oliver Falk <oliver@linux-kernel.at>		- 0.13-1
- Update

* Wed Aug 10 2005 Oliver Falk <oliver@linux-kernel.at>		- 0.12-1
- Update
- Added saidar manpage

* Fri Jul 08 2005 Oliver Falk <oliver@linux-kernel.at>		- 0.11.1-3
- Included examples/*.c in doc

* Wed Jul  6 2005 Tom "spot" Callaway <tcallawa@redhat.com> 0.11.1-2
- a lot of fixes for Fedora Extras

* Thu May 19 2005 Oliver Falk <oliver@linux-kernel.at>		- 0.11.1-1.1
- Specfile cleanup

* Sun Apr 03 2005 Oliver Falk <oliver@linux-kernel.at>		- 0.11.1-1
- Update

* Fri Mar 25 2005 Oliver Falk <oliver@linux-kernel.at>		- 0.11-2.1
- Fix rpmlint warnings

* Tue Feb 15 2005 Oliver Falk <oliver@linux-kernel.at>		- 0.11-2
- Don't require coreutils. They are normally installed on Fedora, but
  not available on RH 8, where the tools are usually also installed.
  Yes, rebuilding with nodeps would also do it, but it's not fine...

* Tue Feb 15 2005 Oliver Falk <oliver@linux-kernel.at>		- 0.11-1
- Initial build for Fedora Core
